<?php

//
// HORIZONT GmbH, Garmischer Str. 8, D-80339 Muenchen
//



    /*
     * This is a configuration file for the Ticket module. Several configuration
     * files (with different names) can be specified to handle different
     * actions.
     *
     * The command of an action in the administration dialog which shall use
     * a configuration file has to be specified like this:
     *   hwm_ticket_call.php?config=<config file name>
     * <config file name> has to be replaced with the name of the proper
     * configuration file, e.g.
     *   hwm_ticket_call.php?config=hwm_ticket_call_config.php
     *
     * Moreover if several actions use similar configurations, there is no need
     * to create an extra configuration file for each action, but the
     * options, which have to be different to those in the configuration file,
     * can be specified in further parameters of hwm_ticket_call.php, like this:
     *   hwm_ticket_call.php?config=my_ticket_config.php&readonly=Y&rejectable=Y
     * The options specified in the call parameters have a higher priority
     * than those in the configuration file.
     */



    $hwm_ticket_call_config = array(
        /*
         * For a report action set readonly to Y, otherwise to N.
         */
        'readonly' => 'N',

        /*
         * If it should be possible to reject the ticket in an activity set to
         * Y, otherwise to N.
         */
        'rejectable' => 'Y',

        /*
         * THIS OPTION CANNOT BE SET BY A CALL PARAMETER!
         * Definition of possible rejects. It is an array of single reject
         * definitions, like this:
         *   <key> => array(<description>, <return code> [, <translate> ])
         * <key> is a unique string, it must not contain the character comma (,)
         *       and it can be used in the option rejects to specified which
         *       reject definitions can be used in the activity.
         * <description> is a string, it is either the description or a
         *       dictionary key.
         * <return code> is a string, it specified the return code of the
         *       activity if the definition has been selected for rejection.
         * <translate> is a string, is optional, if the value is 'Y' or 'y'
         *       the <description> is handled as a dictionary key, otherwise
         *       it is not translated, which is also the default.
         */
        'possible_rejects' => array(
            'REQUESTOR' => array('REQUESTOR', '1', 'N'),
        ),

        /*
         * A comma separated list of keys defined in the option
         * possible_rejects. Only rejects specified here are displayed for
         * selection when the activity shall be rejected.
         */
        'rejects' => 'REQUESTOR',   // rejects are finally configured in process config   

        /*
         * Specifies whether a special HOS reject has to be called (if set to Y)
         * or not (if set to N) which is the default behavior. This option takes
         * effect only if the ticket dialog is embedded in a HOS controlled
         * process (e.g. JCL, TWSz, etc.).
         */
        'hos_reject' => 'Y',

        /*
         * Name prefixes of the ticket parameters and triggered parameters
         * specified in the Global/Process definition dialog.
         */
        'param_prefix' => 'UAT_',
        'param_prefix_trigger' => '',

        /*
         * Form name of the ticket dialog generated into the dialog HTML.
         */
        'form_name' => 'frmTicket',

        /*
         * If a nonempty string is specified here, the text set is being
         * displayed before the activity ends, to remaind the user that it is
         * almost finished.
         */
        'ok_question' => '',

        /*
         * If a nonempty string is specified here, the text set is being
         * displayed before the activity is discarded, to remaind the user that
         * the changes will get lost.
         */
        'discard_question' => 'hwm_mMemoConfirmDiscard',

        /*
         * If the textarea memo field has to be displayed set to Y, otherwise to
         * N.
         */
        'memo_visible' => 'N',

        /*
         * If the textarea memo field must contain a nonempty value set to Y,
         * otherwise to N.
         */
        'memo_mandatory' => 'N',

        /*
         * Specifies the vertical size of the displayed textarea memo field.
         */
        'memo_rows' => '20',

        /*
         * Specifies the horizontal size of the displayed textarea memo field.
         */
        'memo_columns' => '100',

        /*
         * Specifies the maximal count of characters which can be written into
         * the memo field. 0 means unlimited.
         */
        'memo_max_len' => '0',

        /*
         * Specifies whether the general process data section is initialy
         * expanded or collapsed in the edit dialog.
         */
        'display_gpd_expanded' => 'N',

        /*
         * Specifies whether the additional process data section is initialy
         * expanded or collapsed in the edit dialog.
         */
        'display_apd_expanded' => 'Y',

        /*
         * Specifies whether the memo history section is initialy expanded or
         * collapsed in the edit dialog.
         */
        'display_mh_expanded' => 'N',

        /*
         * Specifies whether the attached files section is initialy
         * expanded or collapsed in the edit dialog.
         */
        'display_af_expanded' => 'N',

        /*
         * Communication ID from the etc/hwm_universal_interface_config.php
         * file. It can be used to specify that an external command shall be
         * executed for every process when the activity finishes. If not
         * defined or set to an empty string, no external command will be
         * executed.
         */
        'exec_ext_cmd_communication' => '',

        /*
         * Command ID from the etc/hwm_executor_config.php file on the external
         * system where the external command shall be executed. It is executed
         * only if a valid communication ID is specified in
         * 'exec_ext_cmd_communication', otherwise it is ignored.
         */
        'exec_ext_cmd_command' => 'hallo_world',



        /*************/
        /*           */
        /*  Cleanup  */
        /*           */
        /*************/

        /*
         * External cleanup script. This option is dedicated for cases when the
         * ticket module is combined with other HOS modules (e.g. HOS_JCL) in
         * one process type.
         * EXAMPLE:
         *   'ext_cleanup' => 'hos_cleanup_jcl.php',
         */
        'ext_cleanup' => 'hos_cleanup_jcl.php',
    );
?>
